@@ -1,7 +1,7 @@
 /*
     Qalculate (GTK UI)
 
-    Copyright (C) 2003-2007, 2008, 2016-2020  Hanna Knutsson (hanna.knutsson@protonmail.com)
+    Copyright (C) 2003-2007, 2008, 2016-2024  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,8 +50,7 @@ struct mode_struct {
 	bool chain_mode;
 	bool complex_angle_form;
 	bool implicit_question_asked;
-	int rounding_mode;
-	bool simplified_percentage;
+	int simplified_percentage;
 	bool concise_uncertainty_input;
 	long int fixed_denominator;
 	std::string custom_angle_unit;
@@ -206,7 +205,7 @@ void set_operator_symbols();
 
 bool update_window_title(const char *str = NULL, bool is_result = false);
 
-cairo_surface_t *draw_structure(MathStructure &m, PrintOptions po = default_print_options, bool caf = false, InternalPrintStruct ips = top_ips, gint *point_central = NULL, int scaledown = 0, GdkRGBA *color = NULL, gint *x_offset = NULL, gint *w_offset = NULL, gint max_width = -1);
+cairo_surface_t *draw_structure(MathStructure &m, PrintOptions po = default_print_options, bool caf = false, InternalPrintStruct ips = top_ips, gint *point_central = NULL, int scaledown = 0, GdkRGBA *color = NULL, gint *x_offset = NULL, gint *w_offset = NULL, gint max_width = -1, bool for_result_widget = true, MathStructure *where_struct = NULL, std::vector<MathStructure> *to_structs = NULL);
 
 void update_status_text();
 
@@ -296,11 +295,11 @@ void convert_in_wUnits(int toFrom = -1);
 
 void convert_to_unit(GtkMenuItem *w, gpointer user_data);
 
-void save_defs();
+bool save_defs(bool allow_cancel = false);
 void save_mode();
 
 void load_preferences();
-void save_preferences(bool mode = false);
+bool save_preferences(bool mode = false, bool allow_cancel = false);
 void edit_preferences();
 
 gint completion_sort_func(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data);
@@ -428,6 +427,13 @@ void on_menu_item_meta_mode_delete_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_quit_activate(GtkMenuItem *w, gpointer user_data);
 void on_colorbutton_status_error_color_color_set(GtkColorButton *w, gpointer user_data);
 void on_colorbutton_status_warning_color_color_set(GtkColorButton *w, gpointer user_data);
+void on_preferences_checkbutton_autocalc_history_toggled(GtkToggleButton *w, gpointer user_data);
+void on_preferences_checkbutton_parsed_in_result_toggled(GtkToggleButton *w, gpointer user_data);
+void on_preferences_combobox_bits_changed(GtkComboBox *w, gpointer user_data);
+void on_preferences_checkbutton_twos_complement_toggled(GtkToggleButton *w, gpointer user_data);
+void on_preferences_checkbutton_hexadecimal_twos_complement_toggled(GtkToggleButton *w, gpointer user_data);
+void on_preferences_checkbutton_twos_complement_input_toggled(GtkToggleButton *w, gpointer user_data);
+void on_preferences_checkbutton_hexadecimal_twos_complement_input_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_persistent_keypad_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_copy_ascii_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_lower_case_numbers_toggled(GtkToggleButton *w, gpointer user_data);
@@ -516,6 +522,7 @@ void on_button_square_clicked();
 void on_button_sqrt_clicked(GtkButton *w, gpointer user_data);
 void on_button_log_clicked(GtkButton *w, gpointer user_data);
 void on_button_ln_clicked(GtkButton *w, gpointer user_data);
+void on_button_twos_in_toggled(GtkToggleButton *w, gpointer);
 void on_menu_item_manage_variables_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_manage_functions_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_manage_units_activate(GtkMenuItem *w, gpointer user_data);
@@ -614,6 +621,8 @@ void on_menu_item_assumptions_nonnegative_activate(GtkMenuItem *w, gpointer user
 void on_menu_item_assumptions_negative_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_assumptions_nonpositive_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_assumptions_unknown_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_expression_status_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_parsed_in_result_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_exact_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_assume_nonzero_denominators_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_abort_activate(GtkMenuItem *w, gpointer user_data);
@@ -668,9 +677,6 @@ void on_menu_item_display_prefixes_for_currencies_activate(GtkMenuItem *w, gpoin
 void on_menu_item_display_prefixes_for_all_units_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_indicate_infinite_series_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_show_ending_zeroes_activate(GtkMenuItem *w, gpointer user_data);
-void on_menu_item_round_halfway_to_even_activate(GtkMenuItem *w, gpointer user_data);
-void on_menu_item_round_halfway_up_activate(GtkMenuItem *w, gpointer user_data);
-void on_menu_item_round_truncate_numbers_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_negative_exponents_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_sort_minus_last_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_fraction_decimal_activate(GtkMenuItem *w, gpointer user_data);
